@@ -5,8 +5,6 @@
 --
 --  Created: 11 Feburary 2006
 --
---  Version $Revision: 1.1 $ from $Date: 2005/12/08 18:12:43 $
---
 --  Copyright (C) 2005 Duncan Coutts, Axel Simon
 --
 --  This library is free software; you can redistribute it and/or
@@ -50,15 +48,12 @@ module Graphics.UI.Gtk.ModelView.TreeStore (
 
 import Data.Bits
 import Data.Word (Word)
-import Data.Maybe ( fromMaybe, isJust, fromJust )
+import Data.Maybe ( fromMaybe, isJust )
 import Data.Tree
 import Control.Monad ( liftM, when )
 import Control.Exception (assert)
 import Data.IORef
-import Data.Tree
-import System.Glib.FFI ( CInt )
 import Graphics.UI.Gtk.ModelView.Types
-import Graphics.UI.Gtk.ModelView.TreeModel
 import Graphics.UI.Gtk.Types (GObjectClass, TreeModelClass)
 import Graphics.UI.Gtk.TreeList.TreePath (TreePath)
 import Graphics.UI.Gtk.ModelView.CustomStore
